package com.ruoyi.base.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.base.mapper.RobotOpsMediaAssetMapper;
import com.ruoyi.base.domain.RobotOpsMediaAsset;
import com.ruoyi.base.service.IRobotOpsMediaAssetService;

/**
 * 素材资源Service业务层处理
 * 
 * @author ruoyi
 * @date 2026-05-08
 */
@Service
public class RobotOpsMediaAssetServiceImpl implements IRobotOpsMediaAssetService 
{
    @Autowired
    private RobotOpsMediaAssetMapper robotOpsMediaAssetMapper;

    /**
     * 查询素材资源
     * 
     * @param id 素材资源主键
     * @return 素材资源
     */
    @Override
    public RobotOpsMediaAsset selectRobotOpsMediaAssetById(Long id)
    {
        return robotOpsMediaAssetMapper.selectRobotOpsMediaAssetById(id);
    }

    /**
     * 查询素材资源列表
     * 
     * @param robotOpsMediaAsset 素材资源
     * @return 素材资源
     */
    @Override
    public List<RobotOpsMediaAsset> selectRobotOpsMediaAssetList(RobotOpsMediaAsset robotOpsMediaAsset)
    {
        return robotOpsMediaAssetMapper.selectRobotOpsMediaAssetList(robotOpsMediaAsset);
    }

    /**
     * 新增素材资源
     * 
     * @param robotOpsMediaAsset 素材资源
     * @return 结果
     */
    @Override
    public int insertRobotOpsMediaAsset(RobotOpsMediaAsset robotOpsMediaAsset)
    {
        robotOpsMediaAsset.setCreateTime(DateUtils.getNowDate());
        return robotOpsMediaAssetMapper.insertRobotOpsMediaAsset(robotOpsMediaAsset);
    }

    /**
     * 修改素材资源
     * 
     * @param robotOpsMediaAsset 素材资源
     * @return 结果
     */
    @Override
    public int updateRobotOpsMediaAsset(RobotOpsMediaAsset robotOpsMediaAsset)
    {
        robotOpsMediaAsset.setUpdateTime(DateUtils.getNowDate());
        return robotOpsMediaAssetMapper.updateRobotOpsMediaAsset(robotOpsMediaAsset);
    }

    /**
     * 批量删除素材资源
     * 
     * @param ids 需要删除的素材资源主键
     * @return 结果
     */
    @Override
    public int deleteRobotOpsMediaAssetByIds(Long[] ids)
    {
        return robotOpsMediaAssetMapper.deleteRobotOpsMediaAssetByIds(ids);
    }

    /**
     * 删除素材资源信息
     * 
     * @param id 素材资源主键
     * @return 结果
     */
    @Override
    public int deleteRobotOpsMediaAssetById(Long id)
    {
        return robotOpsMediaAssetMapper.deleteRobotOpsMediaAssetById(id);
    }
}
